==> adcolony_flutter-1.3.1%2B2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:adcolony_flutter/adcolony_flutter.dart';
import 'package:adcolony_flutter/banner.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  final zones = [
    'vz9a841ab586ae4d72b9',
    'vz4eacd40a32ad4fd69c',
    'vz09f26f8ad3c340c484'
  ];
  @override
  void initState() {
    super.initState();
    AdColony.init(AdColonyOptions('app4f4659d279be4554ad', '0', this.zones));
  }

  listener(AdColonyAdListener event, int reward) {
    print(event);
    if (event == AdColonyAdListener.onRequestFilled) AdColony.show(listener);
    if (event == AdColonyAdListener.onReward) {
      print('ADCOLONY: $reward');
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('AdColony Plugin example app'),
        ),
        body: Center(
          child: ListView(
            children: <Widget>[
              RaisedButton(
                onPressed: () async {
                  if (await AdColony.isLoaded()) {
      
                    AdColony.request(this.zones[1]);
                  }
                },
                child: Text('Show Interstitial'),
              ),
              RaisedButton(
                onPressed: () async {
                  if (await AdColony.isLoaded()) {
                    
                    AdColony.request(this.zones[1]);
                  }
                },
                child: Text('Show Interstitial Rewarded'),
              ),
              BannerView(listener, BannerSizes.banner, this.zones[2]),
              BannerView(listener, BannerSizes.medium, this.zones[2]),
              BannerView(listener, BannerSizes.skyscraper, this.zones[2]),
              BannerView(listener, BannerSizes.leaderboard, this.zones[2]),
            ],
          ),
        ),
      ),
    );
  }
}

==> adcolony_flutter-1.3.5%2B2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:adcolony_flutter/adcolony_flutter.dart';
import 'package:adcolony_flutter/banner.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  final zones = [
    'vz9a841ab586ae4d72b9',
    'vz4eacd40a32ad4fd69c',
    'vz09f26f8ad3c340c484'
  ];
  @override
  void initState() {
    super.initState();
    AdColony.init(AdColonyOptions('app4f4659d279be4554ad', '0', this.zones));
  }

   listener(AdColonyAdListener event, int reward) async {
    print(event);
    if (event == AdColonyAdListener.onRequestFilled) {
      if(await AdColony.isLoaded()) {
          AdColony.show();
      }
    }
    if(event == AdColonyAdListener.onReward) {
      print('ADCOLONY: $reward');
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: ListView(
            children: <Widget>[
              RaisedButton(
                onPressed: () => AdColony.request(this.zones[1], listener),
                child: Text('Show Interstitial'),
              ),
              RaisedButton(
                onPressed: () async => AdColony.request(this.zones[3], listener),
                child: Text('Show Interstitial Rewarded'),
              ),
              BannerView(listener, BannerSizes.banner, this.zones[2]),
              BannerView(listener, BannerSizes.medium, this.zones[2]),
              BannerView(listener, BannerSizes.skyscraper, this.zones[2]),
              BannerView(listener, BannerSizes.leaderboard, this.zones[2]),
            ],
          ),
        ),
      ),
    );
  }
}
